using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Collections.Specialized;
using OSGeo.MapGuide;
using System.Collections;


public class UtilityClass
{
    MgSiteConnection siteConnection;
    String selectionResult;
    String selectionXML;

    public String SelectionResult
    {
        get { return selectionResult; }
        set { selectionResult = value; }
    }

    public String SelectionXML
    {
        get { return selectionXML; }
        set { selectionXML = value; }
    }

    public NameValueCollection GetParameters(HttpRequest Request)
    {
        return Request.HttpMethod == "GET" ? Request.QueryString : Request.Form;
    }

    public void InitializeWebTier(HttpRequest Request)
    {
        string realPath = Request.ServerVariables["APPL_PHYSICAL_PATH"];
        String configPath = realPath + "webconfig.ini";
        MapGuideApi.MgInitializeWebTier(configPath);
    }

    public void ConnectToServer(String sessionID)
    {
        MgUserInformation userInfo = new MgUserInformation(sessionID);
        siteConnection = new MgSiteConnection();
        siteConnection.Open(userInfo);
    }

    public void CreateSelectionXML(String queryString)
    {
        MgResourceService resService = (MgResourceService)siteConnection.CreateService(MgServiceType.ResourceService);
        MgFeatureService featureService = (MgFeatureService)siteConnection.CreateService(MgServiceType.FeatureService);

        MgMap map = new MgMap();
        map.Open(resService, "Sheboygan");
        MgLayerBase layer = map.GetLayers().GetItem("Parcels");
        MgResourceIdentifier resId = new MgResourceIdentifier(layer.GetFeatureSourceId());
        MgFeatureQueryOptions queryOption = new MgFeatureQueryOptions();
        queryOption.SetFilter(queryString);
        MgFeatureReader featureReader = featureService.SelectFeatures(resId, "Parcels", queryOption);

        MgSelection selection = new MgSelection(map);
        selection.AddFeatures(layer, featureReader, 0);

        OutputSelectionInHTML(selection, featureService);

        selectionXML = selection.ToXml();
    }

    public void OutputSelectionInHTML(MgSelection selection, MgFeatureService featureService)
    {
        MgReadOnlyLayerCollection layers = selection.GetLayers();
        String outString = null;
        MgFeatureReader featReader = null;

        if (layers != null)
        {
            for (int i = 0; i < layers.GetCount(); i++)
            {
                MgLayerBase layer = layers.GetItem(i);
                if ((layer != null) && (layer.GetName() == "Parcels"))
                {
                    //Please type in the code between the comments
                    String layerClassName = layer.GetFeatureClassName();
                    String selectString = selection.GenerateFilter(layer, layerClassName);

                    String layerFeatureIdString = layer.GetFeatureSourceId();
                    MgResourceIdentifier layerResId = new MgResourceIdentifier(layerFeatureIdString);

                    MgFeatureQueryOptions queryOptions = new MgFeatureQueryOptions();
                    queryOptions.SetFilter(selectString);
                    featReader = featureService.SelectFeatures(layerResId, layerClassName, queryOptions);

                    /////////////////////////////////////////////////
                    outString = outString + "<table border=\"1\">\n";

                    double acre = 0;

                    while (featReader.ReadNext())
                    {
                        outString = outString + "<tr>\n";

                        outString = outString + "<td>";
                        outString = outString + featReader.GetString("RNAME");
                        outString = outString + "</td>\n";


                        outString = outString + "<td>";
                        outString = outString + featReader.GetString("RPROPAD");
                        outString = outString + "</td>\n";

                        outString = outString + "<td>";
                        String acreString = featReader.GetString("RACRE");
                        acre = acre + (acreString == "" ? 0 : Convert.ToDouble(acreString));
                        outString = outString + acreString;
                        outString = outString + "</tr>\n";

                    }
                    outString = outString + "</table>\n";
                }
            }

        }

        selectionResult = outString;
    }

    public int ListSelections(String mapName)
    {
        MgSelection mapSelection = null;
        MgResourceService resService = (MgResourceService)siteConnection.CreateService(MgServiceType.ResourceService);
        MgFeatureService featService = (MgFeatureService)siteConnection.CreateService(MgServiceType.FeatureService);

        //Type in the code between the comments
        MgMap map = new MgMap();
        map.Open(resService, mapName);

        mapSelection = new MgSelection(map);
        mapSelection.Open(resService, mapName);
        /////////////////////////////////////////////

        if (mapSelection.GetLayers() != null)
        {
            OutputSelectionInHTML(mapSelection, featService);
            return 1;
        }
        else
        {
            return 0;
        }
    }

    public ArrayList MakeQuery(int districtNum, String name)
    {
        ArrayList list = null;
        //Type in the code between the comments
        MgResourceService resService = (MgResourceService)siteConnection.CreateService(MgServiceType.ResourceService);

        MgMap map = new MgMap(siteConnection);
        map.Open(resService, "Sheboygan");

        MgFeatureQueryOptions districtQuery = new MgFeatureQueryOptions();
        districtQuery.SetFilter("Autogenerated_SDF_ID = " + districtNum);

        MgLayer layer = map.GetLayers().GetItem("Districts") as MgLayer;
        MgFeatureReader featureReader = layer.SelectFeatures(districtQuery);

        featureReader.ReadNext();
        MgByteReader geometryBytes = featureReader.GetGeometry("Data");
        MgAgfReaderWriter agfReader = new MgAgfReaderWriter();
        MgGeometry districtGeometry = agfReader.Read(geometryBytes);

        MgFeatureQueryOptions nameQuery = new MgFeatureQueryOptions();
        nameQuery.SetFilter("RNAME LIKE '" + name + "%'");
        nameQuery.SetSpatialFilter("SHPGEOM", districtGeometry, MgFeatureSpatialOperations.Inside);

        MgResourceIdentifier parcelId = new MgResourceIdentifier("Library://Samples/Sheboygan/Data/Parcels.FeatureSource");
        layer = map.GetLayers().GetItem("Parcels") as MgLayer;
        featureReader = layer.SelectFeatures(nameQuery);

        list = new ArrayList();
        while (featureReader.ReadNext())
        {
            list.Add(featureReader.GetString("RPROPAD"));
        }

        /////////////////////////////////////////////

        return list;
    }
}
